@@ -8,6 +8,7 @@ from sbdk.auth import push_url, push_json
 from sbdk.commands import check_project_dir, check_image, check_project_data
 from sbdk.docker import make_runner
 from sbdk.error import SbdkError
+from sbdk.docker.container import dockerize
 
 
 def argument_parser(subparsers):
@@ -67,11 +68,12 @@ def push_schema(project, container):
         exit(1)
 
     push_data = {'message': container.message or 'NO COMMIT MESSAGE',
-                 'image_data': {'id': project.docker_registry_name + '/' + container.user + '/' + project.name,
+                 'image_data': {'id': container.repository,
                                 'tag': container.tag},
                  'wrappers': wrapper_data}
+
     if project.schema_server_url:
-        url = push_url(project, project.state['username'])
+        url = push_url(project, dockerize(project.state['username']))
         try:
             push_json(url, push_data, container.token)
         except requests.HTTPError as e:
@@ -86,6 +88,7 @@ def check_container_push(container, retries=2):
     if retries < 0:
         return False
     docker_repo, image_id = container.repository, container.tag
+
     check_image = requests.get('%s://%s/v1/repositories/%s/%s/images'
                                % tuple([container.project.docker_registry_schema] + docker_repo.split('/')))
     check_tag = requests.get('%s://%s/v1/repositories/%s/%s/tags'
