@@ -24,7 +24,7 @@ def upload(project, file):
         sys.exit(1)
     file = os.path.abspath(file)
     usr, sid = login(project)
-    user_home = '/home/%s' % usr
+    user_home = '/Stash/%s' % usr
     dest = os.path.join(user_home, os.path.basename(file))
     cwd = os.path.abspath('.')
     args = [executable, '-o', 'u', '-sessionId', '-s', server, '-ssl', '-lf', file, '-rf', dest]
