@@ -25,7 +25,7 @@ class Runner(object):
         self.docker_config = kwargs
         self.last_container = None
 
-    def run(self, command, entrypoint=None):
+    def run(self, command, entrypoint=None, retry=5):
         volumes = {'/sb': {}, Runner.WORKING_DIR: {}}
         volumes.update(self.docker_config.pop('Volumes', {}))
         binds = {self.sb_dir: "/sb:rw",
@@ -58,7 +58,15 @@ class Runner(object):
                 cont = self.client.create_container_from_config(config)
             else:
                 raise
-        self.client.start(container=cont, binds=binds)
+        try:
+            self.client.start(container=cont, binds=binds)
+        except APIError:
+            if retry > 0:
+                logging.error('Failed to run container. Retries left: %s', retry-1)
+                return self.run(command, entrypoint, retry-1)
+            else:
+                logging.error('Failed to run container. Retries exceeded!')
+                raise
         self.last_container = Container(self.client, self.project, cont)
         return self.last_container
 
