@@ -1,6 +1,6 @@
 from .schema_based import SchemaBased
 from .base_attr import BaseAttr
-from .validators import validate_file_type
+from .validators import validate_file_type, validate_file_exists
 from .io_value import IOValue
 from .io_list import IOList
 
@@ -12,13 +12,13 @@ class IOAttr(BaseAttr):
 
     def __call__(self, attr_name, data=None):
         data = BaseAttr.__call__(self, attr_name, data)
-        return IOList(data) if self.list else IOValue(data)
+        return IOList(data) if self.list else (IOValue(data) if data else None)
 
     def validate(self, instance):
         BaseAttr.validate(self, instance)
         if instance:
             validate_file_type(instance, self.types, list=self.list)
-#            validate_file_exists(instance, list=self.list)
+            validate_file_exists(instance, list=self.list)
         elif self.required:
             raise ValueError('This input is required')
 
@@ -40,12 +40,11 @@ class IODef(SchemaBased):
 
     def _save_meta(self):
         for v in self:
-            v.value._save_meta()
+            if v.value:
+                v.value._save_meta()
 
     def _load_meta(self):
         for v in self:
-            getattr(self, v.id)._load_meta()
-
-
-
-
+            val = getattr(self, v.id)
+            if val and hasattr(val, '_load_meta'):
+                val._load_meta()
