@@ -120,9 +120,10 @@ class StructAttr(BaseParam):
         validate_struct(instance, list=self.list)
 
     def __call__(self, attr_name, data=None):
+        to_dict = lambda o: o.__json__() if hasattr(o, '__json__') else o or {}
         BaseParam.__call__(self, attr_name, data)
         if not self.list:
-            return self.schema(**(data or {}))
+            return self.schema(**to_dict(data))
         if not data:
             return []
-        return [self.schema(**(item or {})) for item in data]
\ No newline at end of file
+        return [self.schema(**to_dict(item)) for item in data]
\ No newline at end of file
